@@ -9,7 +9,7 @@ Class, Function
 __copyright__ = 'Copyright (C) 2021 @koKkekoh'
 __license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.29.1' # 2021-11-12
+__version__ = '0.29.2' # 2021-11-17
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 import re, pathlib
@@ -30,6 +30,7 @@ from sphinx.util.nodes import process_index_entry
 from sphinx.writers import html5
 
 import sphindexer as idxr
+from sphindexer.rack import UNIT_CLSF, UNIT_TERM, UNIT_SBTM
 
 logger = logging.getLogger(__name__)
 
@@ -70,7 +71,7 @@ def parser_for_kana_text(separator, option_marker):
     return re.compile(ahead + re_kana + re_word + re_mark)
 
 #オプションに「a-z」があるか
-_a2z = re.compile(r'[a-z]')
+_a2z = re.compile(r'[a-zA-Z]')
 
 #「かな|単語^オプション」のオプションの変換用
 _s2i_each_together = {
@@ -198,9 +199,9 @@ class KanaText(nodes.Element):
     def __eq__(self, other):
         """unittest用"""
         try:
-            return self.assort() == other.assort()
+            return self.as_identifier() == other.as_identifier()
         except AttributeError:
-            return self.assort() == other
+            return self.as_identifier() == other
 
     def __str__(self):
         """jinja2用"""
@@ -267,13 +268,22 @@ class KanaText(nodes.Element):
         return self._as_standard()
 
     def assort(self):
-        return self._as_identifier()
+        if self.whatiam != 'classifier':
+            return self.as_identifier()
+
+        key = self.as_identifier()
+        if len(key) != 1:
+            return (1, key)
+        elif _a2z.match(key) or key.isnumeric():
+            return (2, key)
+        else:
+            return (1, key)
 
     def _as_standard(self):
         if self['ideo']: return self['ideo']
         return ''
 
-    def _as_identifier(self):
+    def as_identifier(self):
         if self['kana']: return self['kana'] + self['delimiter'] + self['ideo']
         if self['ideo']: return self['ideo']
         return ''
@@ -405,54 +415,12 @@ class ExtIndexUnit(idxr.IndexUnit):
         return terms
 
 
-# ------------------------------------------------------------
-
-
-_each_words = re.compile(r' *; +')
-
-
 class ExtIndexEntry(idxr.IndexEntry):
 
     textclass = KanaText
     packclass = ExtSubterm
     unitclass = ExtIndexUnit
 
-    def __init__(self, rawtext, entry_type='single', file_name=None, target=None, main='',
-                 index_key=''):
-
-        super().__init__(rawtext, entry_type, file_name, target, main, index_key)
-
-    def __repr__(self):
-        """
-        doctest:
-
-            >>> ktext = ExtIndexEntry('壱壱; 弐弐')
-            >>> ktext
-            <ExtIndexEntry: entry_type='single' <KanaText: len=1 <#text: '壱壱'>><KanaText: len=1 <#text: '弐弐'>>>
-            >>> ktext = ExtIndexEntry('ああ|壱壱^')
-            >>> ktext
-            <ExtIndexEntry: entry_type='single' <KanaText: len=2 ruby='on' <#text: 'ああ|壱壱'>>>
-            >>> ktext = ExtIndexEntry('あ|壱^1')
-            >>> ktext
-            <ExtIndexEntry: entry_type='single' <KanaText: len=2 ruby='specific' option='1' <#text: 'あ|壱'>>>
-        """
-
-        name = self.__class__.__name__
-        prop = f"<{name}: "
-
-        etype, ikey = self['entry_type'], self['index_key']
-        main, fn, tid = self['main'], self['file_name'], self['target']
-        if etype: prop += f"entry_type='{etype}' "
-        if main : prop += f"main='{main}' "
-        if fn   : prop += f"file_name='{fn}' "
-        if tid  : prop += f"target='{tid}' "
-        if ikey : prop += f"index_key='{ikey}' "
-
-        children = ''.join([c.entity_of_repr() for c in self])
-        prop += children + ">"
-
-        return prop
-
 
 # ------------------------------------------------------------
 
@@ -543,8 +511,6 @@ class ExtIndexRack(idxr.IndexRack):
     5. self.generate_genindex_data() genindex用データの生成.
     """
 
-    UNIT_CLSF, UNIT_TERM, UNIT_SBTM = 0, 1, 2
-
     textclass = KanaText
     packclass = ExtSubterm
     unitclass = ExtIndexUnit
@@ -590,7 +556,7 @@ class ExtIndexRack(idxr.IndexRack):
         """
         # 情報収集
         self.put_in_kana_catalog(unit['main'], unit.get_terms())
-        unit[self.UNIT_TERM].kana_text_on_genindex = self.config.kana_text_on_genindex
+        unit[UNIT_TERM].kana_text_on_genindex = self.config.kana_text_on_genindex
 
         # 残りの処理
         super().append(unit)
@@ -647,17 +613,17 @@ class ExtIndexRack(idxr.IndexRack):
 
         # カタログ情報を使った更新/kana_text_change_tripleの反映
         for unit in self._rack:
-            assert [unit[self.UNIT_TERM]]
+            assert [unit[UNIT_TERM]]
 
             # 各termの読みの設定（「同じ単語は同じ読み」とする）
 
-            self.update_term_with_kana_catalog(unit[self.UNIT_TERM])
+            self.update_term_with_kana_catalog(unit[UNIT_TERM])
 
-            for subterm in unit[self.UNIT_SBTM]:
+            for subterm in unit[UNIT_SBTM]:
                 self.update_term_with_kana_catalog(subterm)
 
             # kana_text_change_tripleの設定値を反映
-            unit[self.UNIT_SBTM].change_triple = self.config.kana_text_change_triple
+            unit[UNIT_SBTM].change_triple = self.config.kana_text_change_triple
 
         super().update_units()
 
